#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "api-ms-win-core-state-helpers-l1-1-0.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn GetRegistryValueWithFallbackW ( hkeyprimary : HKEY , pwszprimarysubkey : ::windows_sys::core::PCWSTR , hkeyfallback : HKEY , pwszfallbacksubkey : ::windows_sys::core::PCWSTR , pwszvalue : ::windows_sys::core::PCWSTR , dwflags : u32 , pdwtype : *mut u32 , pvdata : *mut ::core::ffi::c_void , cbdatain : u32 , pcbdataout : *mut u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegCloseKey ( hkey : HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegConnectRegistryA ( lpmachinename : ::windows_sys::core::PCSTR , hkey : HKEY , phkresult : *mut HKEY ) -> super::super::Foundation:: WIN32_ERROR );
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`*"] fn RegConnectRegistryExA ( lpmachinename : ::windows_sys::core::PCSTR , hkey : HKEY , flags : u32 , phkresult : *mut HKEY ) -> i32 );
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`*"] fn RegConnectRegistryExW ( lpmachinename : ::windows_sys::core::PCWSTR , hkey : HKEY , flags : u32 , phkresult : *mut HKEY ) -> i32 );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegConnectRegistryW ( lpmachinename : ::windows_sys::core::PCWSTR , hkey : HKEY , phkresult : *mut HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegCopyTreeA ( hkeysrc : HKEY , lpsubkey : ::windows_sys::core::PCSTR , hkeydest : HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegCopyTreeW ( hkeysrc : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , hkeydest : HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegCreateKeyA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR , phkresult : *mut HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`, `\"Win32_Security\"`*"] fn RegCreateKeyExA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR , reserved : u32 , lpclass : ::windows_sys::core::PCSTR , dwoptions : REG_OPEN_CREATE_OPTIONS , samdesired : REG_SAM_FLAGS , lpsecurityattributes : *const super::super::Security:: SECURITY_ATTRIBUTES , phkresult : *mut HKEY , lpdwdisposition : *mut REG_CREATE_KEY_DISPOSITION ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`, `\"Win32_Security\"`*"] fn RegCreateKeyExW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , reserved : u32 , lpclass : ::windows_sys::core::PCWSTR , dwoptions : REG_OPEN_CREATE_OPTIONS , samdesired : REG_SAM_FLAGS , lpsecurityattributes : *const super::super::Security:: SECURITY_ATTRIBUTES , phkresult : *mut HKEY , lpdwdisposition : *mut REG_CREATE_KEY_DISPOSITION ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`, `\"Win32_Security\"`*"] fn RegCreateKeyTransactedA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR , reserved : u32 , lpclass : ::windows_sys::core::PCSTR , dwoptions : REG_OPEN_CREATE_OPTIONS , samdesired : REG_SAM_FLAGS , lpsecurityattributes : *const super::super::Security:: SECURITY_ATTRIBUTES , phkresult : *mut HKEY , lpdwdisposition : *mut REG_CREATE_KEY_DISPOSITION , htransaction : super::super::Foundation:: HANDLE , pextendedparemeter : *const ::core::ffi::c_void ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`, `\"Win32_Security\"`*"] fn RegCreateKeyTransactedW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , reserved : u32 , lpclass : ::windows_sys::core::PCWSTR , dwoptions : REG_OPEN_CREATE_OPTIONS , samdesired : REG_SAM_FLAGS , lpsecurityattributes : *const super::super::Security:: SECURITY_ATTRIBUTES , phkresult : *mut HKEY , lpdwdisposition : *mut REG_CREATE_KEY_DISPOSITION , htransaction : super::super::Foundation:: HANDLE , pextendedparemeter : *const ::core::ffi::c_void ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegCreateKeyW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , phkresult : *mut HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegDeleteKeyA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegDeleteKeyExA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR , samdesired : u32 , reserved : u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegDeleteKeyExW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , samdesired : u32 , reserved : u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegDeleteKeyTransactedA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR , samdesired : u32 , reserved : u32 , htransaction : super::super::Foundation:: HANDLE , pextendedparameter : *const ::core::ffi::c_void ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegDeleteKeyTransactedW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , samdesired : u32 , reserved : u32 , htransaction : super::super::Foundation:: HANDLE , pextendedparameter : *const ::core::ffi::c_void ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegDeleteKeyValueA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR , lpvaluename : ::windows_sys::core::PCSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegDeleteKeyValueW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , lpvaluename : ::windows_sys::core::PCWSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegDeleteKeyW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegDeleteTreeA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegDeleteTreeW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegDeleteValueA ( hkey : HKEY , lpvaluename : ::windows_sys::core::PCSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegDeleteValueW ( hkey : HKEY , lpvaluename : ::windows_sys::core::PCWSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegDisablePredefinedCache ( ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegDisablePredefinedCacheEx ( ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegDisableReflectionKey ( hbase : HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegEnableReflectionKey ( hbase : HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegEnumKeyA ( hkey : HKEY , dwindex : u32 , lpname : ::windows_sys::core::PSTR , cchname : u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegEnumKeyExA ( hkey : HKEY , dwindex : u32 , lpname : ::windows_sys::core::PSTR , lpcchname : *mut u32 , lpreserved : *const u32 , lpclass : ::windows_sys::core::PSTR , lpcchclass : *mut u32 , lpftlastwritetime : *mut super::super::Foundation:: FILETIME ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegEnumKeyExW ( hkey : HKEY , dwindex : u32 , lpname : ::windows_sys::core::PWSTR , lpcchname : *mut u32 , lpreserved : *const u32 , lpclass : ::windows_sys::core::PWSTR , lpcchclass : *mut u32 , lpftlastwritetime : *mut super::super::Foundation:: FILETIME ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegEnumKeyW ( hkey : HKEY , dwindex : u32 , lpname : ::windows_sys::core::PWSTR , cchname : u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegEnumValueA ( hkey : HKEY , dwindex : u32 , lpvaluename : ::windows_sys::core::PSTR , lpcchvaluename : *mut u32 , lpreserved : *const u32 , lptype : *mut u32 , lpdata : *mut u8 , lpcbdata : *mut u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegEnumValueW ( hkey : HKEY , dwindex : u32 , lpvaluename : ::windows_sys::core::PWSTR , lpcchvaluename : *mut u32 , lpreserved : *const u32 , lptype : *mut u32 , lpdata : *mut u8 , lpcbdata : *mut u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegFlushKey ( hkey : HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`, `\"Win32_Security\"`*"] fn RegGetKeySecurity ( hkey : HKEY , securityinformation : u32 , psecuritydescriptor : super::super::Security:: PSECURITY_DESCRIPTOR , lpcbsecuritydescriptor : *mut u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegGetValueA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR , lpvalue : ::windows_sys::core::PCSTR , dwflags : REG_ROUTINE_FLAGS , pdwtype : *mut REG_VALUE_TYPE , pvdata : *mut ::core::ffi::c_void , pcbdata : *mut u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegGetValueW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , lpvalue : ::windows_sys::core::PCWSTR , dwflags : REG_ROUTINE_FLAGS , pdwtype : *mut REG_VALUE_TYPE , pvdata : *mut ::core::ffi::c_void , pcbdata : *mut u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegLoadAppKeyA ( lpfile : ::windows_sys::core::PCSTR , phkresult : *mut HKEY , samdesired : u32 , dwoptions : u32 , reserved : u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegLoadAppKeyW ( lpfile : ::windows_sys::core::PCWSTR , phkresult : *mut HKEY , samdesired : u32 , dwoptions : u32 , reserved : u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegLoadKeyA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR , lpfile : ::windows_sys::core::PCSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegLoadKeyW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , lpfile : ::windows_sys::core::PCWSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegLoadMUIStringA ( hkey : HKEY , pszvalue : ::windows_sys::core::PCSTR , pszoutbuf : ::windows_sys::core::PSTR , cboutbuf : u32 , pcbdata : *mut u32 , flags : u32 , pszdirectory : ::windows_sys::core::PCSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegLoadMUIStringW ( hkey : HKEY , pszvalue : ::windows_sys::core::PCWSTR , pszoutbuf : ::windows_sys::core::PWSTR , cboutbuf : u32 , pcbdata : *mut u32 , flags : u32 , pszdirectory : ::windows_sys::core::PCWSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegNotifyChangeKeyValue ( hkey : HKEY , bwatchsubtree : super::super::Foundation:: BOOL , dwnotifyfilter : REG_NOTIFY_FILTER , hevent : super::super::Foundation:: HANDLE , fasynchronous : super::super::Foundation:: BOOL ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegOpenCurrentUser ( samdesired : u32 , phkresult : *mut HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegOpenKeyA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR , phkresult : *mut HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegOpenKeyExA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR , uloptions : u32 , samdesired : REG_SAM_FLAGS , phkresult : *mut HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegOpenKeyExW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , uloptions : u32 , samdesired : REG_SAM_FLAGS , phkresult : *mut HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegOpenKeyTransactedA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR , uloptions : u32 , samdesired : REG_SAM_FLAGS , phkresult : *mut HKEY , htransaction : super::super::Foundation:: HANDLE , pextendedparemeter : *const ::core::ffi::c_void ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegOpenKeyTransactedW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , uloptions : u32 , samdesired : REG_SAM_FLAGS , phkresult : *mut HKEY , htransaction : super::super::Foundation:: HANDLE , pextendedparemeter : *const ::core::ffi::c_void ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegOpenKeyW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , phkresult : *mut HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegOpenUserClassesRoot ( htoken : super::super::Foundation:: HANDLE , dwoptions : u32 , samdesired : u32 , phkresult : *mut HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegOverridePredefKey ( hkey : HKEY , hnewhkey : HKEY ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegQueryInfoKeyA ( hkey : HKEY , lpclass : ::windows_sys::core::PSTR , lpcchclass : *mut u32 , lpreserved : *const u32 , lpcsubkeys : *mut u32 , lpcbmaxsubkeylen : *mut u32 , lpcbmaxclasslen : *mut u32 , lpcvalues : *mut u32 , lpcbmaxvaluenamelen : *mut u32 , lpcbmaxvaluelen : *mut u32 , lpcbsecuritydescriptor : *mut u32 , lpftlastwritetime : *mut super::super::Foundation:: FILETIME ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegQueryInfoKeyW ( hkey : HKEY , lpclass : ::windows_sys::core::PWSTR , lpcchclass : *mut u32 , lpreserved : *const u32 , lpcsubkeys : *mut u32 , lpcbmaxsubkeylen : *mut u32 , lpcbmaxclasslen : *mut u32 , lpcvalues : *mut u32 , lpcbmaxvaluenamelen : *mut u32 , lpcbmaxvaluelen : *mut u32 , lpcbsecuritydescriptor : *mut u32 , lpftlastwritetime : *mut super::super::Foundation:: FILETIME ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegQueryMultipleValuesA ( hkey : HKEY , val_list : *mut VALENTA , num_vals : u32 , lpvaluebuf : ::windows_sys::core::PSTR , ldwtotsize : *mut u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegQueryMultipleValuesW ( hkey : HKEY , val_list : *mut VALENTW , num_vals : u32 , lpvaluebuf : ::windows_sys::core::PWSTR , ldwtotsize : *mut u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegQueryReflectionKey ( hbase : HKEY , bisreflectiondisabled : *mut super::super::Foundation:: BOOL ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegQueryValueA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR , lpdata : ::windows_sys::core::PSTR , lpcbdata : *mut i32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegQueryValueExA ( hkey : HKEY , lpvaluename : ::windows_sys::core::PCSTR , lpreserved : *const u32 , lptype : *mut REG_VALUE_TYPE , lpdata : *mut u8 , lpcbdata : *mut u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegQueryValueExW ( hkey : HKEY , lpvaluename : ::windows_sys::core::PCWSTR , lpreserved : *const u32 , lptype : *mut REG_VALUE_TYPE , lpdata : *mut u8 , lpcbdata : *mut u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegQueryValueW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , lpdata : ::windows_sys::core::PWSTR , lpcbdata : *mut i32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegRenameKey ( hkey : HKEY , lpsubkeyname : ::windows_sys::core::PCWSTR , lpnewkeyname : ::windows_sys::core::PCWSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegReplaceKeyA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR , lpnewfile : ::windows_sys::core::PCSTR , lpoldfile : ::windows_sys::core::PCSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegReplaceKeyW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , lpnewfile : ::windows_sys::core::PCWSTR , lpoldfile : ::windows_sys::core::PCWSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegRestoreKeyA ( hkey : HKEY , lpfile : ::windows_sys::core::PCSTR , dwflags : REG_RESTORE_KEY_FLAGS ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegRestoreKeyW ( hkey : HKEY , lpfile : ::windows_sys::core::PCWSTR , dwflags : REG_RESTORE_KEY_FLAGS ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`, `\"Win32_Security\"`*"] fn RegSaveKeyA ( hkey : HKEY , lpfile : ::windows_sys::core::PCSTR , lpsecurityattributes : *const super::super::Security:: SECURITY_ATTRIBUTES ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`, `\"Win32_Security\"`*"] fn RegSaveKeyExA ( hkey : HKEY , lpfile : ::windows_sys::core::PCSTR , lpsecurityattributes : *const super::super::Security:: SECURITY_ATTRIBUTES , flags : REG_SAVE_FORMAT ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`, `\"Win32_Security\"`*"] fn RegSaveKeyExW ( hkey : HKEY , lpfile : ::windows_sys::core::PCWSTR , lpsecurityattributes : *const super::super::Security:: SECURITY_ATTRIBUTES , flags : REG_SAVE_FORMAT ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`, `\"Win32_Security\"`*"] fn RegSaveKeyW ( hkey : HKEY , lpfile : ::windows_sys::core::PCWSTR , lpsecurityattributes : *const super::super::Security:: SECURITY_ATTRIBUTES ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`, `\"Win32_Security\"`*"] fn RegSetKeySecurity ( hkey : HKEY , securityinformation : u32 , psecuritydescriptor : super::super::Security:: PSECURITY_DESCRIPTOR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegSetKeyValueA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR , lpvaluename : ::windows_sys::core::PCSTR , dwtype : u32 , lpdata : *const ::core::ffi::c_void , cbdata : u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegSetKeyValueW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , lpvaluename : ::windows_sys::core::PCWSTR , dwtype : u32 , lpdata : *const ::core::ffi::c_void , cbdata : u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegSetValueA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR , dwtype : REG_VALUE_TYPE , lpdata : ::windows_sys::core::PCSTR , cbdata : u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegSetValueExA ( hkey : HKEY , lpvaluename : ::windows_sys::core::PCSTR , reserved : u32 , dwtype : REG_VALUE_TYPE , lpdata : *const u8 , cbdata : u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegSetValueExW ( hkey : HKEY , lpvaluename : ::windows_sys::core::PCWSTR , reserved : u32 , dwtype : REG_VALUE_TYPE , lpdata : *const u8 , cbdata : u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegSetValueW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR , dwtype : REG_VALUE_TYPE , lpdata : ::windows_sys::core::PCWSTR , cbdata : u32 ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegUnLoadKeyA ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[cfg(feature = "Win32_Foundation")]
::windows_targets::link ! ( "advapi32.dll""system" #[doc = "*Required features: `\"Win32_System_Registry\"`, `\"Win32_Foundation\"`*"] fn RegUnLoadKeyW ( hkey : HKEY , lpsubkey : ::windows_sys::core::PCWSTR ) -> super::super::Foundation:: WIN32_ERROR );
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const AGP_FLAG_NO_1X_RATE: i32 = 1i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const AGP_FLAG_NO_2X_RATE: i32 = 2i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const AGP_FLAG_NO_4X_RATE: i32 = 4i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const AGP_FLAG_NO_8X_RATE: i32 = 8i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const AGP_FLAG_NO_FW_ENABLE: i32 = 512i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const AGP_FLAG_NO_SBA_ENABLE: i32 = 256i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const AGP_FLAG_REVERSE_INITIALIZATION: i32 = 128i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const AGP_FLAG_SPECIAL_RESERVE: i32 = 1015808i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const AGP_FLAG_SPECIAL_TARGET: i32 = 1048575i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const APMMENUSUSPEND_DISABLED: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const APMMENUSUSPEND_ENABLED: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const APMMENUSUSPEND_NOCHANGE: u32 = 128u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const APMMENUSUSPEND_UNDOCKED: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const APMTIMEOUT_DISABLED: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const BIF_RAWDEVICENEEDSDRIVER: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const BIF_SHOWSIMILARDRIVERS: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_BOOT_DEVICE: u32 = 262144u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_CANTSTOPACHILD: u32 = 128u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_DISABLED: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_FAILEDINSTALL: u32 = 64u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_FINISHINSTALL_ACTION: u32 = 131072u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_FINISHINSTALL_UI: u32 = 65536u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_FINISH_INSTALL: u32 = 1024u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_IGNORE_BOOT_LC: u32 = 8u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_MANUAL_INSTALL: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_NEEDS_CLASS_CONFIG: u32 = 524288u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_NEEDS_FORCED_CONFIG: u32 = 2048u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_NETBOOT_CARD: u32 = 4096u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_NET_BOOT: u32 = 16u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_NOREMOVEEXIT: u32 = 512u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_OKREMOVEROM: u32 = 256u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_PARTIAL_LOG_CONF: u32 = 8192u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_REINSTALL: u32 = 32u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_REMOVED: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_SUPPRESS_SURPRISE: u32 = 16384u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CONFIGFLAG_VERIFY_HARDWARE: u32 = 32768u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CSCONFIGFLAG_BITS: u32 = 7u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CSCONFIGFLAG_DISABLED: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CSCONFIGFLAG_DO_NOT_CREATE: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const CSCONFIGFLAG_DO_NOT_START: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DMSTATEFLAG_APPLYTOALL: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DOSOPTF_ALWAYSUSE: i32 = 4i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DOSOPTF_DEFAULT: i32 = 1i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DOSOPTF_INDOSSTART: i32 = 64i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DOSOPTF_MULTIPLE: i32 = 128i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DOSOPTF_NEEDSETUP: i32 = 32i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DOSOPTF_PROVIDESUMB: i32 = 16i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DOSOPTF_SUPPORTED: i32 = 2i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DOSOPTF_USESPMODE: i32 = 8i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DOSOPTGF_DEFCLEAN: i32 = 1i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DRIVERSIGN_BLOCKING: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DRIVERSIGN_NONE: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DRIVERSIGN_WARNING: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DTRESULTFIX: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DTRESULTOK: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DTRESULTPART: u32 = 3u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const DTRESULTPROB: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const EISAFLAG_NO_IO_MERGE: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const EISAFLAG_SLOT_IO_FIRST: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const EISA_NO_MAX_FUNCTION: u32 = 255u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const HKEY_CLASSES_ROOT: HKEY = -2147483648i32 as _;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const HKEY_CURRENT_CONFIG: HKEY = -2147483643i32 as _;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const HKEY_CURRENT_USER: HKEY = -2147483647i32 as _;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const HKEY_CURRENT_USER_LOCAL_SETTINGS: HKEY = -2147483641i32 as _;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const HKEY_DYN_DATA: HKEY = -2147483642i32 as _;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const HKEY_LOCAL_MACHINE: HKEY = -2147483646i32 as _;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const HKEY_PERFORMANCE_DATA: HKEY = -2147483644i32 as _;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const HKEY_PERFORMANCE_NLSTEXT: HKEY = -2147483552i32 as _;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const HKEY_PERFORMANCE_TEXT: HKEY = -2147483568i32 as _;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const HKEY_USERS: HKEY = -2147483645i32 as _;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const IT_COMPACT: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const IT_CUSTOM: u32 = 3u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const IT_PORTABLE: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const IT_TYPICAL: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const LASTGOOD_OPERATION: u32 = 255u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const LASTGOOD_OPERATION_DELETE: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const LASTGOOD_OPERATION_NOPOSTPROC: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const MF_FLAGS_CREATE_BUT_NO_SHOW_DISABLED: u32 = 8u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const MF_FLAGS_EVEN_IF_NO_RESOURCE: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const MF_FLAGS_FILL_IN_UNKNOWN_RESOURCE: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const MF_FLAGS_NO_CREATE_IF_NO_RESOURCE: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const NUM_EISA_RANGES: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const NUM_RESOURCE_MAP: u32 = 256u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PCIC_DEFAULT_IRQMASK: u32 = 20152u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PCIC_DEFAULT_NUMSOCKETS: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PCI_OPTIONS_USE_BIOS: i32 = 1i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PCI_OPTIONS_USE_IRQ_STEERING: i32 = 2i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PCMCIA_DEF_MEMBEGIN: u32 = 786432u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PCMCIA_DEF_MEMEND: u32 = 16777215u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PCMCIA_DEF_MEMLEN: u32 = 4096u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PCMCIA_DEF_MIN_REGION: u32 = 65536u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PCMCIA_OPT_AUTOMEM: i32 = 4i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PCMCIA_OPT_HAVE_SOCKET: i32 = 1i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PCMCIA_OPT_NO_APMREMOVE: i32 = 32i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PCMCIA_OPT_NO_AUDIO: i32 = 16i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PCMCIA_OPT_NO_SOUND: i32 = 8i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_OPTION_DEFAULT: u32 = 15u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_OPTION_ENABLED: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_OPTION_MSSPEC: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_OPTION_REALMODE: u32 = 8u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_OPTION_REGISTRY: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_DISABLED: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_ENABLED: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_ERROR: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_MAX: u32 = 3u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_MINIPORT_COMPATIBLE: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_MINIPORT_ERROR: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_MINIPORT_INVALID: u32 = 7u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_MINIPORT_MAX: u32 = 8u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_MINIPORT_NOKEY: u32 = 5u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_MINIPORT_NONE: u32 = 3u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_MINIPORT_NORMAL: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_MINIPORT_OVERRIDE: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_MINIPORT_SUCCESS: u32 = 6u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_TABLE_BAD: u32 = 5u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_TABLE_ERROR: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_TABLE_MAX: u32 = 7u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_TABLE_MSSPEC: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_TABLE_NONE: u32 = 3u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_TABLE_REALMODE: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_TABLE_REGISTRY: u32 = 0u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PIR_STATUS_TABLE_SUCCESS: u32 = 6u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const PROVIDER_KEEPS_VALUE_LENGTH: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGDF_CONFLICTDMA: u32 = 524288u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGDF_CONFLICTIO: u32 = 65536u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGDF_CONFLICTIRQ: u32 = 262144u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGDF_CONFLICTMEM: u32 = 131072u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGDF_GENFORCEDCONFIG: u32 = 32u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGDF_MAPIRQ2TO9: u32 = 1048576u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGDF_NEEDFULLCONFIG: u32 = 16u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGDF_NODETCONFIG: u32 = 32768u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGDF_NOTDETDMA: u32 = 8u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGDF_NOTDETIO: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGDF_NOTDETIRQ: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGDF_NOTDETMEM: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGDF_NOTVERIFIED: u32 = 2147483648u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_DATA_NETOS_IPX: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IPX");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_DATA_NETOS_NDIS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NDIS");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_DATA_NETOS_ODI: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ODI");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_DEFAULT_INSTANCE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("0000");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_ACPIENUM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ACPI");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_APM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("*PNP0C05");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_BIOSENUM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BIOS");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_CLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Class");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_CONFIG: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Config");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_CONTROL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Control");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_CRASHES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Crashes");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_CURRENT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Current");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_CURRENT_ENV: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("\\Windows 4.0");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_DANGERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Dangers");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_DEFAULT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Default");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_DETMODVARS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DetModVars");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_DEVICEPARAMETERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Device Parameters");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_DEVICE_PROPERTIES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Properties");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_DISPLAY_CLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Display");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_DOSOPTCDROM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CD-ROM");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_DOSOPTMOUSE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MOUSE");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_DRIVERPARAMETERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Driver Parameters");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_DRIVERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("\\Drivers");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_EBDAUTOEXECBATKEYBOARD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EBDAutoexecBatKeyboard");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_EBDAUTOEXECBATLOCAL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EBDAutoexecBatLocale");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_EBDCONFIGSYSKEYBOARD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EBDConfigSysKeyboard");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_EBDCONFIGSYSLOCAL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EBDConfigSysLocale");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_EBDFILESKEYBOARD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EBDFilesKeyboard");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_EBDFILESLOCAL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EBDFilesLocale");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_EISAENUM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EISA");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_ENUM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Enum");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_EXPLORER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Explorer");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_FILTERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Filters");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_INIUPDATE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IniUpdate");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_ISAENUM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ISAPnP");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_JOYCURR: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CurrentJoystickSettings");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_JOYSETTINGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("JoystickSettings");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_KEYBOARD_CLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Keyboard");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_KNOWNDOCKINGSTATES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Hardware Profiles");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_LOGCONFIG: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LogConfig");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_LOGON: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("\\Logon");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_LOWER_FILTER_LEVEL_DEFAULT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("*Lower");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_MEDIA_CLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MEDIA");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_MODEM_CLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Modem");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_MODES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Modes");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_MONITOR_CLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Monitor");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_MOUSE_CLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Mouse");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_NDISINFO: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NDISInfo");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_NETWORK: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Network");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_NETWORKPROVIDER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("\\NetworkProvider");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_NETWORK_PERSISTENT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("\\Persistent");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_NETWORK_RECENT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("\\Recent");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_OVERRIDE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Override");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_PCIENUM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PCI");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_PCMCIA: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PCMCIA\\");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_PCMCIAENUM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PCMCIA");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_PCMCIA_CLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PCMCIA");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_PCMTD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MTD-");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_PCUNKNOWN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UNKNOWN_MANUFACTURER");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_POL_COMPUTERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Computers");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_POL_DEFAULT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!(".default");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_POL_USERGROUPDATA: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("GroupData\\UserGroups\\Priority");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_POL_USERGROUPS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UserGroups");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_POL_USERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Users");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_PORTS_CLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ports");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_PRINTERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Printers");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_PRINT_PROC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("\\Print Processors");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_ROOTENUM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Root");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_RUNHISTORY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RunHistory");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_SCSI_CLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SCSIAdapter");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_SETUP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("\\Setup");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_SHARES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Network\\LanMan");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_SYSTEM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_SYSTEMBOARD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("*PNP0C01");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_UPPER_FILTER_LEVEL_DEFAULT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("*Upper");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_USER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("User");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_VPOWERDENUM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("VPOWERD");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_KEY_WINOLDAPP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("WinOldApp");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_ATT_PC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AT&T PC");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_HP_VECTRA: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HP Vectra");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PC");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPCAT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PC/AT");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPCCONV: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PC Convertible");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPCJR: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PCjr");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPCXT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PC/XT");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPCXT_286: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PC/XT 286");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPS1: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PS/1");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPS2_25: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PS/2-25");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPS2_30: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PS/2-30");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPS2_30_286: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PS/2-30 286");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPS2_50: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PS/2-50");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPS2_50Z: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PS/2-50Z");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPS2_55SX: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PS/2-55SX");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPS2_60: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PS/2-60");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPS2_65SX: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PS/2-65SX");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPS2_70: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PS/2-70");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPS2_70_80: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PS/2-70/80");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPS2_80: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PS/2-80");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPS2_90: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PS/2-90");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_IBMPS2_P70: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IBM PS/2-P70");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_PHOENIX_PCAT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Phoenix PC/AT Compatible");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_UNKNOWN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Unknown");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MACHTYPE_ZENITH_PC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Zenith PC");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_MAX_VALUE_LENGTH: u32 = 256u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_ADDRARB: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Services\\Arbitrators\\AddrArb");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_AEDEBUG: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows NT\\CurrentVersion\\AeDebug");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_APPEARANCE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Control Panel\\Appearance");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_APPPATCH: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\SessionManager\\AppPatches");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_APPPATHS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\App Paths");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_BIOSINFO: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\BiosInfo");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_BUSINFORMATION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\PnP\\BusInformation");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CDFS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\FileSystem\\CDFS");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CHECKBADAPPS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\SessionManager\\CheckBadApps");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CHECKBADAPPS400: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\SessionManager\\CheckBadApps400");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CHECKDISK: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Applets\\Check Drive");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CHECKDISKSET: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Settings");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CHECKDISKUDRVS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoUnknownDDErrDrvs");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CHECKVERDLLS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\SessionManager\\CheckVerDLLs");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CHILD_PREFIX: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Child");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CHKLASTCHECK: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Applets\\Check Drive\\LastCheck");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CHKLASTSURFAN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Applets\\Check Drive\\LastSurfaceAnalysis");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Services\\Class");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CLASS_NT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\Class");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CODEPAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\Nls\\Codepage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CODEVICEINSTALLERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\CoDeviceInstallers");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_COLORS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Control Panel\\Colors");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_COMPUTRNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\ComputerName\\ComputerName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CONTROLPANEL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Control Panel");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CONTROLSFOLDER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Controls Folder");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CRITICALDEVICEDATABASE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\CriticalDeviceDatabase");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CURRENTCONTROLSET: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CURRENT_CONTROL_SET: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CURSORS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Control Panel\\Cursors");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_CVNETWORK: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Network");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_DESKTOP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Control Panel\\Desktop");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_DETECT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Detect");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_DEVICEINSTALLER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Device Installer");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_DEVICE_CLASSES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\DeviceClasses");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_DIFX: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\DIFX");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_DISPLAYSETTINGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Display\\Settings");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_DMAARB: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Services\\Arbitrators\\DMAArb");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_DRIVERSIGN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Driver Signing");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_DRIVERSIGN_POLICY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Policies\\Microsoft\\Windows NT\\Driver Signing");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_ENUM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Enum");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_ENVIRONMENTS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\Print\\Environments");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_EVENTLABELS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AppEvents\\EventLabels");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_EXPLORER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Explorer");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_FAULT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Fault");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_FILESYSTEM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\FileSystem");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_FILESYSTEM_NOVOLTRACK: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\FileSystem\\NoVolTrack");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_FLOATINGPOINTPROCESSOR: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HARDWARE\\DESCRIPTION\\System\\FloatingPointProcessor");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_FLOATINGPOINTPROCESSOR0: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HARDWARE\\DESCRIPTION\\System\\FloatingPointProcessor\\0");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_FONTS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Display\\Fonts");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_GRPCONV: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\GrpConv");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_HACKINIFILE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\SessionManager\\HackIniFiles");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_HWPROFILES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Hardware Profiles");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_HWPROFILESCURRENT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Hardware Profiles\\Current");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_ICONS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Control Panel\\Icons");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_IDCONFIGDB: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\IDConfigDB");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_INSTALLEDFILES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\InstalledFiles");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_IOARB: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Services\\Arbitrators\\IOArb");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_IOS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Services\\VxD\\IOS");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_IRQARB: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Services\\Arbitrators\\IRQArb");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_KEYBOARD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Control Panel\\Keyboard");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_KNOWN16DLLS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\SessionManager\\Known16DLLs");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_KNOWNDLLS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\SessionManager\\KnownDLLs");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_KNOWNVXDS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\SessionManager\\KnownVxDs");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_LASTBACKUP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\LastBackup");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_LASTCHECK: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\LastCheck");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_LASTGOOD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\LastKnownGoodRecovery\\LastGood");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_LASTGOODTMP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\LastKnownGoodRecovery\\LastGood.Tmp");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_LASTOPTIMIZE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\LastOptimize");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_LOOKSCHEMES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Control Panel\\Appearance\\Schemes");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_METRICS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Control Panel\\Desktop\\WindowMetrics");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_MONITORS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\Print\\Monitors");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_MOUSE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Control Panel\\Mouse");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_MSDOSOPTS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\MS-DOSOptions");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_MULTIMEDIA_AUDIO: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Multimedia\\Audio");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_MULTI_FUNCTION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MF");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_NCPSERVER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Services\\NcpServer\\Parameters");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_NETEQUIV: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Network\\Equivalent");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_NETWORK_USERSETTINGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Network");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_NEWDOSBOX: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\MS-DOSSpecialConfig");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_NONDRIVERSIGN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Non-Driver Signing");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_NONDRIVERSIGN_POLICY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Policies\\Microsoft\\Windows NT\\Non-Driver Signing");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_NOSUGGMSDOS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\NoMSDOSWarn");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_NT_CURRENTVERSION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows NT\\CurrentVersion");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_NWREDIR: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Services\\VxD\\NWREDIR");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_PCIIR: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\Pnp\\PciIrqRouting");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_PER_HW_ID_STORAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows NT\\CurrentVersion\\PerHwIdStorage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_PIFCONVERT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\PIFConvert");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_POLICIES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Policies");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_PRINT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\Print");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_PRINTERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\Print\\Printers");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_PROPERTYSYSTEM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\PropertySystem");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_PROVIDERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\Print\\Providers");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_PWDPROVIDER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\PwdProvider");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_REALMODENET: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Network\\Real Mode Net");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_REINSTALL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Reinstall");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_RELIABILITY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Reliability");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_RELIABILITY_POLICY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Policies\\Microsoft\\Windows NT\\Reliability");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_RELIABILITY_POLICY_REPORTSNAPSHOT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ReportSnapshot");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_RELIABILITY_POLICY_SHUTDOWNREASONUI: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ShutdownReasonUI");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_RELIABILITY_POLICY_SNAPSHOT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Snapshot");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_ROOT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Enum\\Root");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_RUN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Run");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_RUNONCE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\RunOnce");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_RUNONCEEX: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\RunOnceEx");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_RUNSERVICES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\RunServices");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_RUNSERVICESONCE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\RunServicesOnce");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_SCHEMES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AppEvents\\Schemes");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_SCREENSAVE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Control Panel\\Desktop");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_SERVICES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Services");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_SETUP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_SHUTDOWN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\Shutdown");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_SOUND: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Control Panel\\Sound");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_SYSTEMENUM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Enum");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_SYSTRAY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Applets\\SysTray");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_TIMEZONE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\TimeZoneInformation");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_UNINSTALL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_UPDATE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\Update");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_VCOMM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Services\\VxD\\VCOMM");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_VMM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Services\\VxD\\VMM");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_VMM32FILES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\VMM32Files");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_VNETSUP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Services\\VxD\\VNETSUP");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_VOLUMECACHE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\VolumeCaches");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_VPOWERD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Services\\VxD\\VPOWERD");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_VXD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Services\\VxD");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_WARNVERDLLS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\SessionManager\\WarnVerDLLs");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_WINBOOT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\WinBoot");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_WINDOWSAPPLETS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Applets");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_WINLOGON: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Software\\Microsoft\\Windows\\CurrentVersion\\Winlogon");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PATH_WMI_SECURITY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("System\\CurrentControlSet\\Control\\Wmi\\Security");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PCI_DUAL_IDE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PCIDualIDE");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_PCI_OPTIONS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Options");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VALUE_DEFAULTLOC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UseDefaultNetLocation");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VALUE_ENABLE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Enable");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VALUE_LOWPOWERACTIVE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ScreenSaveLowPowerActive");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VALUE_LOWPOWERTIMEOUT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ScreenSaveLowPowerTimeout");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VALUE_NETPATH: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NetworkPath");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VALUE_POWEROFFACTIVE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ScreenSavePowerOffActive");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VALUE_POWEROFFTIMEOUT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ScreenSavePowerOffTimeout");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VALUE_SCRPASSWORD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ScreenSave_Data");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VALUE_USESCRPASSWORD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ScreenSaveUsePassword");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VALUE_VERBOSE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Verbose");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ACDRIVESPINDOWN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ACDriveSpinDown");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ACSPINDOWNPREVIOUS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ACSpinDownPrevious");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ACTIVESERVICE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ActiveService");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ADDRESS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Address");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_AEDEBUG_AUTO: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Auto");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_AEDEBUG_DEBUGGER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Debugger");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ALPHANUMPWDS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AlphanumPwds");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_APISUPPORT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("APISupport");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_APMACTIMEOUT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("APMACTimeout");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_APMBATTIMEOUT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("APMBatTimeout");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_APMBIOSVER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("APMBiosVer");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_APMFLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("APMFlags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_APMMENUSUSPEND: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("APMMenuSuspend");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_APMSHUTDOWNPOWER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("APMShutDownPower");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_APPINSTPATH: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AppInstallPath");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ASKFORCONFIG: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AskForConfig");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ASKFORCONFIGFUNC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AskForConfigFunc");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ASYNCFILECOMMIT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AsyncFileCommit");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_AUDIO_BITMAP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("bitmap");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_AUDIO_ICON: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("icon");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_AUTHENT_AGENT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AuthenticatingAgent");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_AUTOEXEC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Autoexec.Bat");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_AUTOINSNOTE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AutoInsertNotification");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_AUTOLOGON: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AutoLogon");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_AUTOMOUNT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AutoMountDrives");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_AUTOSTART: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AutoStart");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BASICPROPERTIES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BasicProperties");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BASICPROPERTIES_32: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BasicProperties32");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BATDRIVESPINDOWN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BatDriveSpinDown");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BATSPINDOWNPREVIOUS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BatSpinDownPrevious");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BEHAVIOR_ON_FAILED_VERIFY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BehaviorOnFailedVerify");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BIOSDATE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BIOSDate");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BIOSNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BIOSName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BIOSVERSION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BIOSVersion");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BITSPERPIXEL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BitsPerPixel");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BOOTCONFIG: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BootConfig");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BOOTCOUNT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BootCount");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BOOTDIR: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BootDir");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BPP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BPP");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("6005BT");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BUFFAGETIMEOUT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BufferAgeTimeout");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BUFFIDLETIMEOUT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BufferIdleTimeout");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_BUSTYPE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BusType");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CAPABILITIES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Capabilities");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CARDSPECIFIC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CardSpecific");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CDCACHESIZE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CacheSize");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CDCOMPATNAMES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MSCDEXCompatNames");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CDEXTERRORS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ExtendedErrors");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CDNOREADAHEAD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoReadAhead");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CDPREFETCH: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Prefetch");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CDPREFETCHTAIL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PrefetchTail");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CDRAWCACHE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RawCache");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CDROM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("GenCD");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CDROMCLASSNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CDROM");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CDSHOWVERSIONS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ShowVersions");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CDSVDSENSE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SVDSense");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CHECKSUM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CurrentChecksum");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Class");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CLASSDESC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ClassDesc");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CLASSGUID: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ClassGUID");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CMDRIVFLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CMDrivFlags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CMENUMFLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CMEnumFlags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_COINSTALLERS_32: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CoInstallers32");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_COMINFO: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ComInfo");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_COMMENT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Comment");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_COMPATIBLEIDS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CompatibleIDs");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_COMPRESSIONMETHOD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CompressionAlgorithm");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_COMPRESSIONTHRESHOLD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CompressionThreshold");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_COMPUTERNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ComputerName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_COMPUTRNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ComputerName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_COMVERIFYBASE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("COMVerifyBase");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CONFIG: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ConfigPath");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CONFIGFLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ConfigFlags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CONFIGMG: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CONFIGMG");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CONFIGSYS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Config.Sys");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CONNECTION_TYPE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ConnectionType");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CONTAINERID: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ContainerID");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CONTIGFILEALLOC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ContigFileAllocSize");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CONVMEM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ConvMem");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CPU: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CPU");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CRASHFUNCS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CrashFuncs");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CSCONFIGFLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CSConfigFlags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CURCONFIG: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CurrentConfig");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CURDRVLET: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CurrentDriveLetterAssignment");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CURRENTCONFIG: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CurrentConfig");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CURRENT_BUILD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CurrentBuildNumber");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CURRENT_CSDVERSION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CSDVersion");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CURRENT_TYPE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CurrentType");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CURRENT_USER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Current User");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CURRENT_VERSION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CurrentVersion");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CUSTOMCOLORS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CustomColors");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CUSTOM_PROPERTY_CACHE_DATE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CustomPropertyCacheDate");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_CUSTOM_PROPERTY_HW_ID_KEY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CustomPropertyHwIdKey");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DEFAULT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Default");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DETCONFIG: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DetConfig");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DETECT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Detect");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DETECTFUNC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DetectFunc");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DETFLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DetFlags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DETFUNC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DetFunc");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DEVDESC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DeviceDesc");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DEVICEDRIVER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DeviceDriver");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DEVICEPATH: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DevicePath");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DEVICE_CHARACTERISTICS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DeviceCharacteristics");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DEVICE_EXCLUSIVE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Exclusive");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DEVICE_INSTANCE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DeviceInstance");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DEVICE_SECURITY_DESCRIPTOR: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Security");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DEVICE_TYPE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DeviceType");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DEVLOADER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DevLoader");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DEVTYPE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DeviceType");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DIRECTHOST: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DirectHost");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DIRTYSHUTDOWN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DirtyShutdown");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DIRTYSHUTDOWNTIME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DirtyShutdownTime");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DISABLECOUNT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DisableCount");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DISABLEPWDCACHING: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DisablePwdCaching");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DISABLEREGTOOLS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DisableRegistryTools");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DISCONNECT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Disconnect");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DISK: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("GenDisk");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DISKCLASSNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DiskDrive");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DISPCPL_NOAPPEARANCEPAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoDispAppearancePage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DISPCPL_NOBACKGROUNDPAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoDispBackgroundPage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DISPCPL_NODISPCPL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoDispCPL");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DISPCPL_NOSCRSAVPAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoDispScrSavPage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DISPCPL_NOSETTINGSPAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoDispSettingsPage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DISPLAY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("display");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DISPLAYFLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DisplayFlags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DOCKED: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CurrentDockedState");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DOCKSTATE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DockState");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DOES_POLLING: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PollingSupportNeeded");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DONTLOADIFCONFLICT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DontLoadIfConflict");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DONTUSEMEM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DontAllocLastMem");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DOSCP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCP");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DOSOPTFLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Flags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DOSOPTGLOBALFLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("GlobalFlags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DOSOPTTIP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("TipText");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DOSPAGER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DOSPager");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DOS_SPOOL_MASK: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DOSSpoolMask");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DOUBLEBUFFER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DoubleBuffer");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DPI: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("dpi");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DPILOGICALX: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DPILogicalX");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DPILOGICALY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DPILogicalY");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DPIPHYSICALX: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DPIPhysicalX");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DPIPHYSICALY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DPIPhysicalY");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DPMS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DPMS");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DRIVER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Driver");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DRIVERCACHEPATH: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DriverCachePath");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DRIVERDATE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DriverDate");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DRIVERDATEDATA: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DriverDateData");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DRIVERVERSION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DriverVersion");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DRIVESPINDOWN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DriveSpinDown");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DRIVEWRITEBEHIND: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DriveWriteBehind");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DRIVE_SPINDOWN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoDispSpinDown");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DRV: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("drv");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DRVDESC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DriverDesc");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_DYNAMIC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Dynamic");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_EISA_FLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EISAFlags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_EISA_FUNCTIONS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EISAFunctions");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_EISA_FUNCTIONS_MASK: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EISAFunctionsMask");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_EISA_RANGES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EISARanges");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_EISA_SIMULATE_INT15: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EISASimulateInt15");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_EJECT_PRIORITY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EjectPriority");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ENABLEINTS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EnableInts");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ENUMERATOR: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Enumerator");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ENUMPROPPAGES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EnumPropPages");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ENUMPROPPAGES_32: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EnumPropPages32");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ESDI: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ESDI\\");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_EXISTS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Exists");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_EXTMEM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ExtMem");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FAULT_LOGFILE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LogFile");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FIFODEPTH: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("FIFODepth");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FILESHARING: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("FileSharing");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FIRSTINSTALLDATETIME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("FirstInstallDateTime");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FIRSTNETDRIVE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("FirstNetworkDrive");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FLOP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("FLOP\\");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FLOPPY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("FLOPPY");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FONTSIZE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("FontSize");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FORCECL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ForceChangeLine");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FORCEDCONFIG: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ForcedConfig");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FORCEFIFO: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ForceFIFO");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FORCELOAD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ForceLoadPD");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FORCEPMIO: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ForcePMIO");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FORCEREBOOT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ForceReboot");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FORCERMIO: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ForceRMIO");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FREESPACERATIO: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("FreeSpaceRatio");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FRIENDLYNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("FriendlyName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FSFILTERCLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("FSFilterClass");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FULLTRACE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("FullTrace");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_FUNCDESC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("FunctionDesc");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_GAPTIME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("GapTime");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_GRB: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("grb");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_HARDWAREID: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HardwareID");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_HIDESHAREPWDS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HideSharePwds");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_HRES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HRes");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_HWDETECT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HardwareDetect");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_HWMECHANISM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HWMechanism");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_HWREV: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HWRevision");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ID: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CurrentID");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_IDE_FORCE_SERIALIZE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ForceSerialization");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_IDE_NO_SERIALIZE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("IDENoSerialize");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_INFNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("InfName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_INFPATH: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("InfPath");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_INFSECTION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("InfSection");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_INFSECTIONEXT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("InfSectionExt");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_INHIBITRESULTS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("InhibitResults");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_INSICON: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Icon");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_INSTALLER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Installer");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_INSTALLER_32: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Installer32");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_INSTALLTYPE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("InstallType");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_INT13: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Int13");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ISAPNP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ISAPNP");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ISAPNP_RDP_OVERRIDE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RDPOverRide");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYCALLOUT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("JoystickCallout");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYNCONFIG: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Joystick%dConfiguration");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYNOEMCALLOUT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Joystick%dOEMCallout");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYNOEMNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Joystick%dOEMName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMCAL1: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCal1");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMCAL10: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCal10");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMCAL11: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCal11");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMCAL12: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCal12");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMCAL2: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCal2");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMCAL3: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCal3");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMCAL4: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCal4");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMCAL5: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCal5");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMCAL6: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCal6");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMCAL7: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCal7");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMCAL8: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCal8");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMCAL9: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCal9");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMCALCAP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCalCap");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMCALLOUT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCallout");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMCALWINCAP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMCalWinCap");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMDATA: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMData");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMPOVLABEL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMPOVLabel");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMRLABEL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMRLabel");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMTESTBUTTONCAP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMTestButtonCap");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMTESTBUTTONDESC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMTestButtonDesc");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMTESTMOVECAP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMTestMoveCap");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMTESTMOVEDESC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMTestMoveDesc");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMTESTWINCAP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMTestWinCap");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMULABEL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMULabel");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMVLABEL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMVLabel");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMXYLABEL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMXYLabel");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYOEMZLABEL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OEMZLabel");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_JOYUSERVALUES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("JoystickUserValues");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LASTALIVEBT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LastAliveBT");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LASTALIVEINTERVAL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("TimeStampInterval");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LASTALIVEPMPOLICY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LastAlivePMPolicy");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LASTALIVESTAMP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LastAliveStamp");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LASTALIVESTAMPFORCED: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LastAliveStampForced");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LASTALIVESTAMPINTERVAL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LastAliveStampInterval");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LASTALIVESTAMPPOLICYINTERVAL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LastAliveStampPolicyInterval");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LASTALIVEUPTIME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LastAliveUptime");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LASTBOOTPMDRVS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LastBootPMDrvs");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LASTCOMPUTERNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LastComputerName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LASTPCIBUSNUM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LastPCIBusNum");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LAST_UPDATE_TIME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LastUpdateTime");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LEGALNOTICECAPTION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LegalNoticeCaption");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LEGALNOTICETEXT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LegalNoticeText");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LICENSINGINFO: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LicensingInfo");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LINKED: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Linked");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LOADHI: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LoadHi");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LOADRMDRIVERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LoadRMDrivers");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LOCATION_INFORMATION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LocationInformation");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LOCATION_INFORMATION_OVERRIDE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LocationInformationOverride");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LOWERFILTERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LowerFilters");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LOWER_FILTER_DEFAULT_LEVEL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LowerFilterDefaultLevel");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_LOWER_FILTER_LEVELS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LowerFilterLevels");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MACHINETYPE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MachineType");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MANUFACTURER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Manufacturer");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MAP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Map");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MATCHINGDEVID: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MatchingDeviceId");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MAXCONNECTIONS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MaxConnections");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MAXLIP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MaxLIP");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MAXRES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MaxResolution");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MAXRETRY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MaxRetry");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MAX_HCID_LEN: u32 = 1024u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MEDIA: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MediaPath");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MFG: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Mfg");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MF_FLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MFFlags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MINIPORT_STAT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MiniportStatus");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MINPWDLEN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MinPwdLen");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MINRETRY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MinRetry");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MODE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Mode");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MODEL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Model");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MSDOSMODE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MSDOSMode");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MSDOSMODEDISCARD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Discard");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_MUSTBEVALIDATED: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MustBeValidated");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NAMECACHECOUNT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NameCache");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NAMENUMERICTAIL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NameNumericTail");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NCP_BROWSEMASTER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("BrowseMaster");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NCP_USEPEERBROWSING: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Use_PeerBrowsing");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NCP_USESAP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Use_Sap");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NDP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NDP");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NETCARD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Netcard");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NETCLEAN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NetClean");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NETOSTYPE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NetOSType");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NETSETUP_DISABLE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoNetSetup");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NETSETUP_NOCONFIGPAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoNetSetupConfigPage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NETSETUP_NOIDPAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoNetSetupIDPage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NETSETUP_NOSECURITYPAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoNetSetupSecurityPage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NOCMOSORFDPT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoCMOSorFDPT");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NODISPLAYCLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoDisplayClass");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NOENTIRENETWORK: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoEntireNetwork");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NOFILESHARING: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoFileSharing");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NOFILESHARINGCTRL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoFileSharingControl");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NOIDE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoIDE");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NOINSTALLCLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoInstallClass");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NONSTANDARD_ATAPI: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NonStandardATAPI");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NOPRINTSHARING: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoPrintSharing");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NOPRINTSHARINGCTRL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoPrintSharingControl");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NOUSECLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoUseClass");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_NOWORKGROUPCONTENTS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoWorkgroupContents");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_OLDMSDOSVER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OldMSDOSVer");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_OLDWINDIR: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OldWinDir");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_OPTIMIZESFN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("OptimizeSFN");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_OPTIONS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Options");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_OPTORDER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Order");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_P1284MDL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Model");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_P1284MFG: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Manufacturer");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PATHCACHECOUNT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PathCache");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PCCARD_POWER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EnablePowerManagement");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PCI: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PCI");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PCIBIOSVER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PCIBIOSVer");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PCICIRQMAP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PCICIRQMap");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PCICOPTIONS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PCICOptions");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PCMCIA_ALLOC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AllocMemWin");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PCMCIA_ATAD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ATADelay");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PCMCIA_MEM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Memory");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PCMCIA_OPT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Options");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PCMCIA_SIZ: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MinRegionSize");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PCMTDRIVER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MTD");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PCSSDRIVER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Driver");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PHYSICALDEVICEOBJECT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PhysicalDeviceObject");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PMODE_INT13: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PModeInt13");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PNPBIOSVER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PnPBIOSVer");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PNPSTRUCOFFSET: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PnPStrucOffset");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_POLICY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Policy");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_POLLING: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Polling");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PORTNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PortName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PORTSUBCLASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PortSubClass");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PREFREDIR: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PreferredRedir");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PRESERVECASE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PreserveCase");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PRESERVELONGNAMES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PreserveLongNames");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PRINTERS_HIDETABS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoPrinterTabs");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PRINTERS_MASK: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PrintersMask");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PRINTERS_NOADD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoAddPrinter");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PRINTERS_NODELETE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoDeletePrinter");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PRINTSHARING: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PrintSharing");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PRIORITY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Priority");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PRIVATE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Private");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PRIVATEFUNC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PrivateFunc");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PRIVATEPROBLEM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PrivateProblem");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PRODUCTID: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ProductId");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PRODUCTTYPE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ProductType");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PROFILEFLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ProfileFlags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PROPERTIES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Properties");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PROTINIPATH: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ProtIniPath");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PROVIDER_NAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ProviderName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PWDEXPIRATION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PwdExpiration");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PWDPROVIDER_CHANGEORDER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ChangeOrder");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PWDPROVIDER_CHANGEPWD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ChangePassword");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PWDPROVIDER_CHANGEPWDHWND: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ChangePasswordHwnd");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PWDPROVIDER_DESC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Description");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PWDPROVIDER_GETPWDSTATUS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("GetPasswordStatus");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PWDPROVIDER_ISNP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NetworkProvider");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_PWDPROVIDER_PATH: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ProviderPath");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_RDINTTHRESHOLD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RDIntThreshold");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_READAHEADTHRESHOLD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ReadAheadThreshold");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_READCACHING: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ReadCaching");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REALNETSTART: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RealNetStart");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REASONCODE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ReasonCode");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REFRESHRATE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RefreshRate");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REGITEMDELETEMESSAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Removal Message");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REGORGANIZATION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RegisteredOrganization");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REGOWNER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RegisteredOwner");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REINSTALL_DEVICEINSTANCEIDS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DeviceInstanceIds");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REINSTALL_DISPLAYNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DisplayName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REINSTALL_STRING: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ReinstallString");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REMOTE_PATH: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RemotePath");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REMOVABLE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Removable");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REMOVAL_POLICY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RemovalPolicy");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REMOVEROMOKAY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RemoveRomOkay");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REMOVEROMOKAYFUNC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RemoveRomOkayFunc");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_RESERVED_DEVNODE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HTREE\\RESERVED\\0");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_RESOLUTION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Resolution");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_RESOURCES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Resources");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_RESOURCE_MAP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ResourceMap");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_RESOURCE_PICKER_EXCEPTIONS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ResourcePickerExceptions");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_RESOURCE_PICKER_TAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ResourcePickerTags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_RESTRICTRUN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RestrictRun");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_RESUMERESET: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ResumeReset");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REVISION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Revision");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_REVLEVEL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RevisionLevel");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_ROOT_DEVNODE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HTREE\\ROOT\\0");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_RUNLOGINSCRIPT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ProcessLoginScript");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SCANNER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SCANNER");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SCAN_ONLY_FIRST: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ScanOnlyFirstDrive");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SCSI: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SCSI\\");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SCSILUN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SCSILUN");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SCSITID: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SCSITargetID");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SEARCHMODE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SearchMode");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SEARCHOPTIONS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SearchOptions");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SECCPL_NOADMINPAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoAdminPage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SECCPL_NOPROFILEPAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoProfilePage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SECCPL_NOPWDPAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoPwdPage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SECCPL_NOSECCPL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoSecCPL");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SERVICE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Service");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SETUPFLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SetupFlags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SETUPMACHINETYPE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SetupMachineType");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SETUPN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SetupN");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SETUPNPATH: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SetupNPath");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SETUPPROGRAMRAN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SetupProgramRan");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHARES_FLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Flags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHARES_PATH: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Path");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHARES_REMARK: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Remark");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHARES_RO_PASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Parm2");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHARES_RW_PASS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Parm1");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHARES_TYPE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Type");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHARE_IRQ: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ForceIRQSharing");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHELLVERSION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ShellVersion");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHOWDOTS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ShowDots");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHOWREASONUI: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ShutdownReasonUI");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHUTDOWNREASON: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ShutdownReason");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHUTDOWNREASON_CODE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ShutdownReasonCode");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHUTDOWNREASON_COMMENT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ShutdownReasonComment");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHUTDOWNREASON_PROCESS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ShutdownReasonProcess");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHUTDOWNREASON_USERNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ShutdownReasonUserName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHUTDOWN_FLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ShutdownFlags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHUTDOWN_IGNORE_PREDEFINED: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ShutdownIgnorePredefinedReasons");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SHUTDOWN_STATE_SNAPSHOT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ShutdownStateSnapshot");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SILENTINSTALL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SilentInstall");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SLSUPPORT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SLSupport");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SOFTCOMPATMODE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SoftCompatMode");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SRCPATH: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SourcePath");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SRVNAMECACHE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ServerNameCache");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SRVNAMECACHECOUNT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ServerNameCacheMax");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SRVNAMECACHENETPROV: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ServerNameCacheNumNets");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_START_ON_BOOT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("StartOnBoot");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_STAT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Status");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_STATICDRIVE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("StaticDrive");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_STATICVXD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("StaticVxD");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_STDDOSOPTION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("StdOption");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SUBMODEL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Submodel");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SUPPORTBURST: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SupportBurst");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SUPPORTLFN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SupportLFN");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SUPPORTTUNNELLING: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SupportTunnelling");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SYMBOLIC_LINK: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SymbolicLink");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SYNCDATAXFER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SyncDataXfer");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SYSDM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SysDM");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SYSDMFUNC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SysDMFunc");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SYSTEMCPL_NOCONFIGPAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoConfigPage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SYSTEMCPL_NODEVMGRPAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoDevMgrPage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SYSTEMCPL_NOFILESYSPAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoFileSysPage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SYSTEMCPL_NOVIRTMEMPAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoVirtMemPage");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SYSTEMROOT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SystemRoot");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SYSTRAYBATFLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PowerFlags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SYSTRAYPCCARDFLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PCMCIAFlags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_SYSTRAYSVCS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Services");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TABLE_STAT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("TableStatus");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TAPE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("TAPE");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TRANSITION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Transition");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TRANSPORT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Transport");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TZACTBIAS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ActiveTimeBias");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TZBIAS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Bias");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TZDLTBIAS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DaylightBias");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TZDLTFLAG: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DaylightFlag");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TZDLTNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DaylightName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TZDLTSTART: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DaylightStart");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TZNOAUTOTIME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DisableAutoDaylightTimeSet");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TZNOCHANGEEND: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoChangeEnd");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TZNOCHANGESTART: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoChangeStart");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TZSTDBIAS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("StandardBias");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TZSTDNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("StandardName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_TZSTDSTART: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("StandardStart");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_UI_NUMBER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UINumber");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_UI_NUMBER_DESC_FORMAT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UINumberDescFormat");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_UNDOCK_WITHOUT_LOGON: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UndockWithoutLogon");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_UNINSTALLER_COMMANDLINE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UninstallString");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_UNINSTALLER_DISPLAYNAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DisplayName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_UPGRADE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Upgrade");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_UPPERFILTERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UpperFilters");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_UPPER_FILTER_DEFAULT_LEVEL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UpperFilterDefaultLevel");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_UPPER_FILTER_LEVELS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UpperFilterLevels");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_USERSETTINGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AdapterSettings");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_USER_NAME: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UserName");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_USRDRVLET: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UserDriveLetterAssignment");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_VDD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("vdd");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_VER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Ver");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_VERIFYKEY: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("VerifyKey");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_VIRTUALHDIRQ: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("VirtualHDIRQ");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_VOLIDLETIMEOUT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("VolumeIdleTimeout");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_VPOWERDFLAGS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Flags");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_VRES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("VRes");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_VXDGROUPS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("VXDGroups");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_WAITFORUNDOCK: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("WaitForUndock");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_WAITFORUNDOCKFUNC: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("WaitForUndockFunc");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_WIN31FILESYSTEM: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Win31FileSystem");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_WIN31PROVIDER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Win31Provider");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_WINBOOTDIR: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("WinbootDir");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_WINCP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ACP");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_WINDIR: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("WinDir");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_WINOLDAPP_DISABLED: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Disabled");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_WINOLDAPP_NOREALMODE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NoRealMode");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_WORKGROUP: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Workgroup");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_WRAPPER: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Wrapper");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_WRINTTHRESHOLD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("WRIntThreshold");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_WRKGRP_FORCEMAPPING: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("WrkgrpForceMapping");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REGSTR_VAL_WRKGRP_REQUIRED: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("WrkgrpRequired");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_KEY_INSTDEV: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Installed");
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_MUI_STRING_TRUNCATE: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_PROCESS_APPKEY: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_SECURE_CONNECTION: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_USE_CURRENT_SECURITY_CONTEXT: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const SUF_BATCHINF: i32 = 4i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const SUF_CLEAN: i32 = 8i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const SUF_EXPRESS: i32 = 2i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const SUF_FIRSTTIME: i32 = 1i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const SUF_INSETUP: i32 = 16i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const SUF_NETHDBOOT: i32 = 64i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const SUF_NETRPLBOOT: i32 = 128i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const SUF_NETSETUP: i32 = 32i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const SUF_SBSCOPYOK: i32 = 256i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const VPDF_DISABLEPWRMGMT: u32 = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const VPDF_DISABLEPWRSTATUSPOLL: u32 = 8u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const VPDF_DISABLERINGRESUME: u32 = 16u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const VPDF_FORCEAPM10MODE: u32 = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const VPDF_SHOWMULTIBATT: u32 = 32u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const VPDF_SKIPINTELSLCHECK: u32 = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub type REG_CREATE_KEY_DISPOSITION = u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_CREATED_NEW_KEY: REG_CREATE_KEY_DISPOSITION = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_OPENED_EXISTING_KEY: REG_CREATE_KEY_DISPOSITION = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub type REG_NOTIFY_FILTER = u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_NOTIFY_CHANGE_NAME: REG_NOTIFY_FILTER = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_NOTIFY_CHANGE_ATTRIBUTES: REG_NOTIFY_FILTER = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_NOTIFY_CHANGE_LAST_SET: REG_NOTIFY_FILTER = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_NOTIFY_CHANGE_SECURITY: REG_NOTIFY_FILTER = 8u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_NOTIFY_THREAD_AGNOSTIC: REG_NOTIFY_FILTER = 268435456u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub type REG_OPEN_CREATE_OPTIONS = u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_OPTION_RESERVED: REG_OPEN_CREATE_OPTIONS = 0u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_OPTION_NON_VOLATILE: REG_OPEN_CREATE_OPTIONS = 0u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_OPTION_VOLATILE: REG_OPEN_CREATE_OPTIONS = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_OPTION_CREATE_LINK: REG_OPEN_CREATE_OPTIONS = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_OPTION_BACKUP_RESTORE: REG_OPEN_CREATE_OPTIONS = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_OPTION_OPEN_LINK: REG_OPEN_CREATE_OPTIONS = 8u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_OPTION_DONT_VIRTUALIZE: REG_OPEN_CREATE_OPTIONS = 16u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub type REG_RESTORE_KEY_FLAGS = i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_FORCE_RESTORE: REG_RESTORE_KEY_FLAGS = 8i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_WHOLE_HIVE_VOLATILE: REG_RESTORE_KEY_FLAGS = 1i32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub type REG_ROUTINE_FLAGS = u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const RRF_RT_DWORD: REG_ROUTINE_FLAGS = 24u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const RRF_RT_QWORD: REG_ROUTINE_FLAGS = 72u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const RRF_RT_REG_NONE: REG_ROUTINE_FLAGS = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const RRF_RT_REG_SZ: REG_ROUTINE_FLAGS = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const RRF_RT_REG_EXPAND_SZ: REG_ROUTINE_FLAGS = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const RRF_RT_REG_BINARY: REG_ROUTINE_FLAGS = 8u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const RRF_RT_REG_DWORD: REG_ROUTINE_FLAGS = 16u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const RRF_RT_REG_MULTI_SZ: REG_ROUTINE_FLAGS = 32u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const RRF_RT_REG_QWORD: REG_ROUTINE_FLAGS = 64u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const RRF_RT_ANY: REG_ROUTINE_FLAGS = 65535u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const RRF_SUBKEY_WOW6464KEY: REG_ROUTINE_FLAGS = 65536u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const RRF_SUBKEY_WOW6432KEY: REG_ROUTINE_FLAGS = 131072u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const RRF_WOW64_MASK: REG_ROUTINE_FLAGS = 196608u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const RRF_NOEXPAND: REG_ROUTINE_FLAGS = 268435456u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const RRF_ZEROONFAILURE: REG_ROUTINE_FLAGS = 536870912u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub type REG_SAM_FLAGS = u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const KEY_QUERY_VALUE: REG_SAM_FLAGS = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const KEY_SET_VALUE: REG_SAM_FLAGS = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const KEY_CREATE_SUB_KEY: REG_SAM_FLAGS = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const KEY_ENUMERATE_SUB_KEYS: REG_SAM_FLAGS = 8u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const KEY_NOTIFY: REG_SAM_FLAGS = 16u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const KEY_CREATE_LINK: REG_SAM_FLAGS = 32u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const KEY_WOW64_32KEY: REG_SAM_FLAGS = 512u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const KEY_WOW64_64KEY: REG_SAM_FLAGS = 256u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const KEY_WOW64_RES: REG_SAM_FLAGS = 768u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const KEY_READ: REG_SAM_FLAGS = 131097u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const KEY_WRITE: REG_SAM_FLAGS = 131078u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const KEY_EXECUTE: REG_SAM_FLAGS = 131097u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const KEY_ALL_ACCESS: REG_SAM_FLAGS = 983103u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub type REG_SAVE_FORMAT = u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_STANDARD_FORMAT: REG_SAVE_FORMAT = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_LATEST_FORMAT: REG_SAVE_FORMAT = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_NO_COMPRESSION: REG_SAVE_FORMAT = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub type REG_VALUE_TYPE = u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_NONE: REG_VALUE_TYPE = 0u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_SZ: REG_VALUE_TYPE = 1u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_EXPAND_SZ: REG_VALUE_TYPE = 2u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_BINARY: REG_VALUE_TYPE = 3u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_DWORD: REG_VALUE_TYPE = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_DWORD_LITTLE_ENDIAN: REG_VALUE_TYPE = 4u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_DWORD_BIG_ENDIAN: REG_VALUE_TYPE = 5u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_LINK: REG_VALUE_TYPE = 6u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_MULTI_SZ: REG_VALUE_TYPE = 7u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_RESOURCE_LIST: REG_VALUE_TYPE = 8u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_FULL_RESOURCE_DESCRIPTOR: REG_VALUE_TYPE = 9u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_RESOURCE_REQUIREMENTS_LIST: REG_VALUE_TYPE = 10u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_QWORD: REG_VALUE_TYPE = 11u32;
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub const REG_QWORD_LITTLE_ENDIAN: REG_VALUE_TYPE = 11u32;
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub struct DSKTLSYSTEMTIME {
    pub wYear: u16,
    pub wMonth: u16,
    pub wDayOfWeek: u16,
    pub wDay: u16,
    pub wHour: u16,
    pub wMinute: u16,
    pub wSecond: u16,
    pub wMilliseconds: u16,
    pub wResult: u16,
}
impl ::core::marker::Copy for DSKTLSYSTEMTIME {}
impl ::core::clone::Clone for DSKTLSYSTEMTIME {
    fn clone(&self) -> Self {
        *self
    }
}
pub type HKEY = isize;
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub struct PVALUEA {
    pub pv_valuename: ::windows_sys::core::PSTR,
    pub pv_valuelen: i32,
    pub pv_value_context: *mut ::core::ffi::c_void,
    pub pv_type: u32,
}
impl ::core::marker::Copy for PVALUEA {}
impl ::core::clone::Clone for PVALUEA {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub struct PVALUEW {
    pub pv_valuename: ::windows_sys::core::PWSTR,
    pub pv_valuelen: i32,
    pub pv_value_context: *mut ::core::ffi::c_void,
    pub pv_type: u32,
}
impl ::core::marker::Copy for PVALUEW {}
impl ::core::clone::Clone for PVALUEW {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub struct REG_PROVIDER {
    pub pi_R0_1val: PQUERYHANDLER,
    pub pi_R0_allvals: PQUERYHANDLER,
    pub pi_R3_1val: PQUERYHANDLER,
    pub pi_R3_allvals: PQUERYHANDLER,
    pub pi_flags: u32,
    pub pi_key_context: *mut ::core::ffi::c_void,
}
impl ::core::marker::Copy for REG_PROVIDER {}
impl ::core::clone::Clone for REG_PROVIDER {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub struct VALENTA {
    pub ve_valuename: ::windows_sys::core::PSTR,
    pub ve_valuelen: u32,
    pub ve_valueptr: usize,
    pub ve_type: REG_VALUE_TYPE,
}
impl ::core::marker::Copy for VALENTA {}
impl ::core::clone::Clone for VALENTA {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub struct VALENTW {
    pub ve_valuename: ::windows_sys::core::PWSTR,
    pub ve_valuelen: u32,
    pub ve_valueptr: usize,
    pub ve_type: REG_VALUE_TYPE,
}
impl ::core::marker::Copy for VALENTW {}
impl ::core::clone::Clone for VALENTW {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub struct val_context {
    pub valuelen: i32,
    pub value_context: *mut ::core::ffi::c_void,
    pub val_buff_ptr: *mut ::core::ffi::c_void,
}
impl ::core::marker::Copy for val_context {}
impl ::core::clone::Clone for val_context {
    fn clone(&self) -> Self {
        *self
    }
}
#[doc = "*Required features: `\"Win32_System_Registry\"`*"]
pub type PQUERYHANDLER = ::core::option::Option<unsafe extern "system" fn(keycontext: *mut ::core::ffi::c_void, val_list: *mut val_context, num_vals: u32, outputbuffer: *mut ::core::ffi::c_void, total_outlen: *mut u32, input_blen: u32) -> u32>;
